pub enum DriverDeviceRequest {
ProgramKey {
wrapped_key: Vec<u8>,
data_unit_size: u32,
responder: DriverDeviceProgramKeyResponder,
},
DeriveRawSecret {
wrapped_key: Vec<u8>,
responder: DriverDeviceDeriveRawSecretResponder,
},
}Expand description
A driver transport variant of the Device protocol.
Variants
ProgramKey
Programs the ephemerally wrapped wrapped_key into the inline encryption hardware in the
next available slot. All slots programmed via the connection this method is called on
will be evicted once the connection is dropped. It is not possible to evict individual keys
(not for any technical reasons; a need for this has not yet arisen). wrapped_key must be
a key wrapped by the inline encryption hardware (in the same session/boot) via a separate
mechanism to this protocol.
Returns
- ZX_ERR_NO_RESOURCES if there are no available key slots.
- ZX_ERR_INVALID_ARGS if
wrapped_keyis not the expected size or if thewrapped_keyfails authentication (e.g. wrapped_key is from a previous boot). - ZX_ERR_TIMED_OUT if the operation times out.
- ZX_ERR_INTERNAL if the operation failed for any other reason.
DeriveRawSecret
Derives a raw software secret from the ephemerally wrapped wrapped_key. wrapped_key
must be a key wrapped by the inline encryption hardware (in the same session/boot) via a
separate mechanism to this protocol. The returned secret can be used for non-inline
cryptographic operations e.g. it can be used for encrypting filesystem metadata not covered
by inline encryption.
Returns
- ZX_ERR_INVALID_ARGS if
wrapped_keyis not the expected size or if thewrapped_keyfails authentication (e.g. wrapped_key is from a previous boot). - ZX_ERR_TIMED_OUT if the operation times out.
- ZX_ERR_INTERNAL if the operation failed for any other reason.
Implementations
Sourceimpl DriverDeviceRequest
impl DriverDeviceRequest
pub fn into_program_key( self, ) -> Option<(Vec<u8>, u32, DriverDeviceProgramKeyResponder)>
pub fn into_derive_raw_secret( self, ) -> Option<(Vec<u8>, DriverDeviceDeriveRawSecretResponder)>
pub fn new_program_key( self, wrapped_key: Vec<u8>, data_unit_size: u32, tx_id: u32, ) -> Self
pub fn new_derive_raw_secret(self, wrapped_key: Vec<u8>, tx_id: u32) -> Self
pub fn program_key_as_message( arena: Arena, wrapped_key: &[u8], data_unit_size: u32, tx_id: u32, ) -> Result<Message<[u8]>, Error>
pub fn derive_raw_secret_as_message( arena: Arena, wrapped_key: &[u8], tx_id: u32, ) -> Result<Message<[u8]>, Error>
pub fn read_from( bytes: &[u8], _handles: &mut [HandleInfo], ) -> Result<Self, Error>
pub fn read_from_message(message: Message<[u8]>) -> Result<(Arena, Self), Error>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL